@@ -1,5 +1,5 @@
 # Copyright (c) 2007-2008 Infrae. All rights reserved.
-# $Id: Native.py 30211 2008-08-13 15:51:02Z sylvain $
+# $Id: Native.py 30495 2008-08-26 12:17:41Z sylvain $
 
 from pysvn import wc_status_kind, opt_revision_kind, wc_notify_action
 import pysvn
@@ -26,7 +26,7 @@ def createSVNClient(recipe):
             path = info['path']
             url = recipe.urls.get(path, None)
             if not (url is None):
-                recipe._updateRevisionInformation(path, url, info['revision'])
+                recipe._updateRevisionInformation(url, path, info['revision'])
 
     client = pysvn.Client()
     client.set_interactive(True)
@@ -44,7 +44,8 @@ class Recipe(BaseRecipe):
         if self.verbose:
             print 'Using pysvn implementation.'
         self.client = createSVNClient(self)
-        self._updateAllRevisionInformation()
+        if not self.export:
+            self._updateAllRevisionInformation()
         self._exportInformationToOptions()
 
 
@@ -52,6 +53,8 @@ class Recipe(BaseRecipe):
         """Update revision information on a path.
         """
         if revision is None:
+            if self.export:
+                return
             info = self.client.info(path)
             revision = info['revision']
 
