@@ -2,7 +2,7 @@
 
 __author__ = "sylvain@infrae.com"
 __format__ = "plaintext"
-__version__ = "$Id: test_impl.py 29941 2008-08-01 12:47:51Z sylvain $"
+__version__ = "$Id: test_impl.py 30366 2008-08-21 16:07:22Z tlotze $"
 
 import unittest
 from doctest import DocFileSuite
@@ -10,6 +10,7 @@ import doctest
 import os, sys
 import os.path
 
+import py
 import infrae.subversion
 import zc.buildout.testing
 import svnhelper.testing
@@ -23,6 +24,7 @@ def setUp(test):
     tested_package = os.path.dirname(infrae.subversion.__file__)
 
     zc.buildout.testing.buildoutSetUp(test)
+    zc.buildout.testing.install('py', test)
     zc.buildout.testing.install_develop('infrae.subversion', test)
     svnhelper.testing.setUpRepository(test)
     test.globs['init_test_package'](test_package)
@@ -36,7 +38,7 @@ def tearDown(test):
     zc.buildout.testing.buildoutTearDown(test)
 
 flags = (doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE |
-         doctest.REPORT_ONLY_FIRST_FAILURE)
+         doctest.REPORT_ONLY_FIRST_FAILURE | doctest.REPORT_NDIFF)
 
 def have_pysvn():
     impl = os.getenv('INFRAE_SUBVERSION_IMPL', 'PYSVN')
